matminer.learners.tests package — matminer 0.1.3 documentation

# matminer.learners.tests package

## Submodules

## matminer.learners.tests.test_volume_predictor module

class `matminer.learners.tests.test_volume_predictor.` `ConditionalVolumePredictorTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `test_predict`()

class `matminer.learners.tests.test_volume_predictor.` `VolumePredictorTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_CsCl`()
  `test_CsCl_ionic`()
  `test_Si`()

## Module contents